"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const SEAPLANE_COMPUTE_API_ENDPOINT = 'https://compute.cplane.cloud/v1';
const SEAPLANE_COORDINATION_API_ENDPOINT = 'https://metadata.cplane.cloud/v1';
const SEAPLANE_IDENTIFY_API_ENDPOINT = 'https://flightdeck.cplane.cloud';
const identify_1 = __importDefault(require("./api/identify"));
const logging_1 = require("./logging");
class Configuration {
    constructor(configValues) {
        this.apiKey = configValues.apiKey;
        this.identifyEndpoint = configValues.identifyEndpoint || SEAPLANE_IDENTIFY_API_ENDPOINT;
        this.computeEndpoint = configValues.computeEndpoint || SEAPLANE_COMPUTE_API_ENDPOINT;
        this.coordinationEndpoint = configValues.coordinationEndpoint || SEAPLANE_COORDINATION_API_ENDPOINT;
        this.autoRenew = configValues.autoRenew || true;
        this.accessToken = configValues.accessToken;
        this.identify = new identify_1.default(this);
    }
    values() {
        return {
            apiKey: this.apiKey,
            identifyEndpoint: this.identifyEndpoint,
            computeEndpoint: this.computeEndpoint,
            coordinationEndpoint: this.coordinationEndpoint,
            autoRenew: this.autoRenew,
        };
    }
    logLevel(level) {
        logging_1.log.level(level);
        if (level == logging_1.SeaLogger.DEBUG) {
            logging_1.log.debug('Seaplane debug activated');
            logging_1.log.debug(`Identify endpoint: ${this.identifyEndpoint}`);
            logging_1.log.debug(`Compute endpoint: ${this.computeEndpoint}`);
            logging_1.log.debug(`Coordination endpoint: ${this.coordinationEndpoint}`);
        }
    }
    logEnable(enable) {
        if (enable) {
            logging_1.log.enable();
        }
        else {
            logging_1.log.disable();
        }
    }
}
exports.default = Configuration;
