"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.log = exports.SeaLogger = void 0;
const winston_1 = require("winston");
class SeaLogger {
    constructor() {
        this.PREFIX = '[Seaplane] ';
        this.transportConsole = new winston_1.transports.Console({
            level: SeaLogger.WARNING,
        });
        this.logger = (0, winston_1.createLogger)({
            transports: [this.transportConsole],
            format: winston_1.format.combine(winston_1.format.label({
                label: this.PREFIX,
            }), winston_1.format.timestamp({
                format: 'MMM-DD-YYYY HH:mm:ss',
            }), winston_1.format.printf((info) => `${info.level}: ${info.label}: ${[info.timestamp]}: ${info.message}`)),
        });
    }
    debug(message) {
        this.logger.debug(message);
    }
    info(message) {
        this.logger.info(message);
    }
    error(message) {
        this.logger.error(message);
    }
    level(level) {
        this.transportConsole.level = level;
    }
    disable() {
        this.transportConsole.level = SeaLogger.CRITICAL;
    }
    enable(level = SeaLogger.WARNING) {
        this.transportConsole.level = level;
    }
}
exports.SeaLogger = SeaLogger;
SeaLogger.CRITICAL = 'crit';
SeaLogger.ERROR = 'error';
SeaLogger.WARNING = 'warning';
SeaLogger.INFO = 'info';
SeaLogger.DEBUG = 'debug';
exports.log = new SeaLogger();
exports.log.level(SeaLogger.WARNING);
