import Request, { headers } from './request';
import { mapToKeyValue, mapToKeyValuePage } from '../model/metadata';
import { encode } from '../utils/base64';
const axios = require('axios'); // eslint-disable-line
export default class Metadata {
    url;
    request;
    constructor(configuration) {
        this.url = `${configuration.values().coordinationEndpoint}/config`;
        this.request = new Request(configuration.identify);
    }
    async set(keyValue) {
        const url = `${this.url}/base64:${encode(keyValue.key)}`;
        const data = encode(keyValue.value);
        console.log(url);
        console.log(data);
        const result = await this.request.send((token) => axios.put(url, data, {
            headers: {
                Authorization: `Bearer ${token}`,
            },
        }));
        return result === 'Ok';
    }
    async get(key) {
        const url = `${this.url}/base64:${encode(key.key)}`;
        const result = await this.request.send((token) => axios.get(url, {
            headers: headers(token),
        }));
        return mapToKeyValue(result);
    }
    async delete(key) {
        const url = `${this.url}/base64:${encode(key.key)}`;
        const result = await this.request.send((token) => axios.delete(url, {
            headers: headers(token),
        }));
        return result === 'Ok';
    }
    async getPage(directory, nextKey) {
        let url = this.url;
        if (directory) {
            url = `${this.url}/base64:${encode(directory.key)}`;
        }
        let params = {};
        if (nextKey) {
            params = {
                form: `${this.url}base64:${encode(nextKey.key)}`,
            };
        }
        const result = await this.request.send((token) => axios.get(url, {
            headers: headers(token),
            params: params,
        }));
        return mapToKeyValuePage(result);
    }
    async getAllPages(directory, nextKey) {
        const pages = [];
        let forNextKey = nextKey;
        while (true) {
            const pageResult = await this.getPage(directory, forNextKey);
            const page = pageResult;
            pages.concat(page.keyValuePairs);
            if (!page.nextKey) {
                forNextKey = page.nextKey;
            }
            else {
                return pages;
            }
        }
    }
}
