import { log } from '../logging';
import { HTTPError } from '../model/errors';
export const headers = (apiKey) => ({
    Accept: 'application/json',
    'Content-Type': 'application/json',
    Authorization: `Bearer ${apiKey}`,
});
export default class Request {
    identify;
    constructor(identify) {
        this.identify = identify;
    }
    async renewIfFails(error, request) {
        const httpError = new HTTPError(error.response.status, JSON.stringify(error.response.data));
        if (error.response.status != 401 || !this.identify.autoRenew) {
            throw httpError;
        }
        log.info('Auto-Renew, renewing the token...');
        const token = await this.identify.renewToken();
        return await request(token);
    }
    async send(request) {
        const accessToken = this.identify.accessToken || (await this.identify.getToken());
        try {
            const { data } = await request(accessToken);
            return data;
        }
        catch (err) { // eslint-disable-line  
            log.error(`Request error: ${err.response.data.title} ${err.response.data.detail}`);
            return await this.renewIfFails(err, request);
        }
    }
}
