const SEAPLANE_COMPUTE_API_ENDPOINT = 'https://compute.cplane.cloud/v1';
const SEAPLANE_COORDINATION_API_ENDPOINT = 'https://metadata.cplane.cloud/v1';
const SEAPLANE_IDENTIFY_API_ENDPOINT = 'https://flightdeck.cplane.cloud';
import Identify from './api/identify';
import { log, SeaLogger } from './logging';
export default class Configuration {
    apiKey;
    identifyEndpoint;
    computeEndpoint;
    coordinationEndpoint;
    autoRenew;
    accessToken;
    identify;
    constructor(configValues) {
        this.apiKey = configValues.apiKey;
        this.identifyEndpoint = configValues.identifyEndpoint || SEAPLANE_IDENTIFY_API_ENDPOINT;
        this.computeEndpoint = configValues.computeEndpoint || SEAPLANE_COMPUTE_API_ENDPOINT;
        this.coordinationEndpoint = configValues.coordinationEndpoint || SEAPLANE_COORDINATION_API_ENDPOINT;
        this.autoRenew = configValues.autoRenew || true;
        this.accessToken = configValues.accessToken;
        this.identify = new Identify(this);
    }
    values() {
        return {
            apiKey: this.apiKey,
            identifyEndpoint: this.identifyEndpoint,
            computeEndpoint: this.computeEndpoint,
            coordinationEndpoint: this.coordinationEndpoint,
            autoRenew: this.autoRenew,
        };
    }
    logLevel(level) {
        log.level(level);
        if (level == SeaLogger.DEBUG) {
            log.debug('Seaplane debug activated');
            log.debug(`Identify endpoint: ${this.identifyEndpoint}`);
            log.debug(`Compute endpoint: ${this.computeEndpoint}`);
            log.debug(`Coordination endpoint: ${this.coordinationEndpoint}`);
        }
    }
    logEnable(enable) {
        if (enable) {
            log.enable();
        }
        else {
            log.disable();
        }
    }
}
