import { createLogger, transports, format } from 'winston';
export class SeaLogger {
    PREFIX = '[Seaplane] ';
    transportConsole = new transports.Console({
        level: SeaLogger.WARNING,
    });
    logger = createLogger({
        transports: [this.transportConsole],
        format: format.combine(format.label({
            label: this.PREFIX,
        }), format.timestamp({
            format: 'MMM-DD-YYYY HH:mm:ss',
        }), format.printf((info) => `${info.level}: ${info.label}: ${[info.timestamp]}: ${info.message}`)),
    });
    static CRITICAL = 'crit';
    static ERROR = 'error';
    static WARNING = 'warning';
    static INFO = 'info';
    static DEBUG = 'debug';
    debug(message) {
        this.logger.debug(message);
    }
    info(message) {
        this.logger.info(message);
    }
    error(message) {
        this.logger.error(message);
    }
    level(level) {
        this.transportConsole.level = level;
    }
    disable() {
        this.transportConsole.level = SeaLogger.CRITICAL;
    }
    enable(level = SeaLogger.WARNING) {
        this.transportConsole.level = level;
    }
}
export const log = new SeaLogger();
log.level(SeaLogger.WARNING);
